==> zio-aws-databasemigration_2.12-5.17.147.1-sources.jar: zio/aws/databasemigration/model/ApplyPendingMaintenanceActionResponse.scala <==
package zio.aws.databasemigration.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ApplyPendingMaintenanceActionResponse(
    resourcePendingMaintenanceActions: Option[
      zio.aws.databasemigration.model.ResourcePendingMaintenanceActions
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.databasemigration.model.ApplyPendingMaintenanceActionResponse = {
    import ApplyPendingMaintenanceActionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.databasemigration.model.ApplyPendingMaintenanceActionResponse
      .builder()
      .optionallyWith(
        resourcePendingMaintenanceActions.map(value => value.buildAwsValue())
      )(_.resourcePendingMaintenanceActions)
      .build()
  }
  def asReadOnly
      : zio.aws.databasemigration.model.ApplyPendingMaintenanceActionResponse.ReadOnly =
    zio.aws.databasemigration.model.ApplyPendingMaintenanceActionResponse
      .wrap(buildAwsValue())
}
object ApplyPendingMaintenanceActionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.databasemigration.model.ApplyPendingMaintenanceActionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.databasemigration.model.ApplyPendingMaintenanceActionResponse =
      zio.aws.databasemigration.model.ApplyPendingMaintenanceActionResponse(
        resourcePendingMaintenanceActions.map(value => value.asEditable)
      )
    def resourcePendingMaintenanceActions: Option[
      zio.aws.databasemigration.model.ResourcePendingMaintenanceActions.ReadOnly
    ]
    def getResourcePendingMaintenanceActions: ZIO[
      Any,
      AwsError,
      zio.aws.databasemigration.model.ResourcePendingMaintenanceActions.ReadOnly
    ] = AwsError.unwrapOptionField(
      "resourcePendingMaintenanceActions",
      resourcePendingMaintenanceActions
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.databasemigration.model.ApplyPendingMaintenanceActionResponse
  ) extends zio.aws.databasemigration.model.ApplyPendingMaintenanceActionResponse.ReadOnly {
    override val resourcePendingMaintenanceActions: Option[
      zio.aws.databasemigration.model.ResourcePendingMaintenanceActions.ReadOnly
    ] = scala
      .Option(impl.resourcePendingMaintenanceActions())
      .map(value =>
        zio.aws.databasemigration.model.ResourcePendingMaintenanceActions
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.databasemigration.model.ApplyPendingMaintenanceActionResponse
  ): zio.aws.databasemigration.model.ApplyPendingMaintenanceActionResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-databasemigration_2.12-6.20.74.2-sources.jar: zio/aws/databasemigration/model/ApplyPendingMaintenanceActionResponse.scala <==
package zio.aws.databasemigration.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ApplyPendingMaintenanceActionResponse(
    resourcePendingMaintenanceActions: Optional[
      zio.aws.databasemigration.model.ResourcePendingMaintenanceActions
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.databasemigration.model.ApplyPendingMaintenanceActionResponse = {
    import ApplyPendingMaintenanceActionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.databasemigration.model.ApplyPendingMaintenanceActionResponse
      .builder()
      .optionallyWith(
        resourcePendingMaintenanceActions.map(value => value.buildAwsValue())
      )(_.resourcePendingMaintenanceActions)
      .build()
  }
  def asReadOnly
      : zio.aws.databasemigration.model.ApplyPendingMaintenanceActionResponse.ReadOnly =
    zio.aws.databasemigration.model.ApplyPendingMaintenanceActionResponse
      .wrap(buildAwsValue())
}
object ApplyPendingMaintenanceActionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.databasemigration.model.ApplyPendingMaintenanceActionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.databasemigration.model.ApplyPendingMaintenanceActionResponse =
      zio.aws.databasemigration.model.ApplyPendingMaintenanceActionResponse(
        resourcePendingMaintenanceActions.map(value => value.asEditable)
      )
    def resourcePendingMaintenanceActions: Optional[
      zio.aws.databasemigration.model.ResourcePendingMaintenanceActions.ReadOnly
    ]
    def getResourcePendingMaintenanceActions: ZIO[
      Any,
      AwsError,
      zio.aws.databasemigration.model.ResourcePendingMaintenanceActions.ReadOnly
    ] = AwsError.unwrapOptionField(
      "resourcePendingMaintenanceActions",
      resourcePendingMaintenanceActions
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.databasemigration.model.ApplyPendingMaintenanceActionResponse
  ) extends zio.aws.databasemigration.model.ApplyPendingMaintenanceActionResponse.ReadOnly {
    override val resourcePendingMaintenanceActions: Optional[
      zio.aws.databasemigration.model.ResourcePendingMaintenanceActions.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.resourcePendingMaintenanceActions())
      .map(value =>
        zio.aws.databasemigration.model.ResourcePendingMaintenanceActions
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.databasemigration.model.ApplyPendingMaintenanceActionResponse
  ): zio.aws.databasemigration.model.ApplyPendingMaintenanceActionResponse.ReadOnly =
    new Wrapper(impl)
}
